Enum cranelift_module::FuncOrDataId [−][src]
A declared name may refer to either a function or data declaration
Variants
Func(FuncId)When it’s a FuncId
Tuple Fields of Func
0: FuncIdData(DataId)When it’s a DataId
Tuple Fields of Data
0: DataIdTrait Implementations
Mapping to ir::ExternalName is trivial based on the FuncId and DataId mapping.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more