Enum cranelift_module::Init [−][src]
This specifies how data is to be initialized.
Variants
UninitializedThis indicates that no initialization has been specified yet.
ZerosInitialize the data with all zeros.
Fields of Zeros
size: usize | The size of the data. |
BytesInitialize the data with the specified contents.
Fields of Bytes
contents: Box<[u8]> | The contents, which also implies the size of the data. |
Methods
impl Init[src]
impl InitTrait Implementations
impl PartialEq for Init[src]
impl PartialEq for Initfn eq(&self, other: &Init) -> bool[src]
fn eq(&self, other: &Init) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Init) -> bool[src]
fn ne(&self, other: &Init) -> boolThis method tests for !=.
impl Eq for Init[src]
impl Eq for Initimpl Debug for Init[src]
impl Debug for Init