Linkage

Enum Linkage 

pub enum Linkage {
    Import,
    Local,
    Preemptible,
    Hidden,
    Export,
}
Linkage refers to where an entity is defined and who can see it.

Variants



Import

Defined outside of a module.



Local

Defined inside the module, but not visible outside it.



Preemptible

Defined inside the module, visible outside it, and may be preempted.



Hidden

Defined inside the module, visible inside the current static linkage unit, but not outside.

A static linkage unit is the combination of all object files passed to a linker to create an executable or dynamic library.



Export

Defined inside the module, and visible outside it.

Implementations

Source

impl Linkage

pub fn is_definable(self) -> bool

Test whether this linkage can have a definition.

pub fn requires_definition(self) -> bool

Test whether this linkage must have a definition.

pub fn is_final(self) -> bool

Test whether this linkage will have a definition that cannot be preempted.