pub struct ModuleNamespace<'a, B: 'a>where
    B: Backend,
{ /* private fields */ }
This provides a view to the state of a module which allows ir::ExternalNames to be translated into FunctionDeclarations and DataDeclarations.

Implementations

Get the FunctionDeclaration for the function named by name.

Get the DataDeclaration for the function named by name.

Get the definition for the function named by name, along with its name and signature.

Get the definition for the data object named by name, along with its name and writable flag

Return whether name names a function, rather than a data object.