Crate cranelift_module
source ·Expand description
Top-level lib.rs for cranelift_module.
Structs
This is to data objects what cranelift_codegen::Context is to functions.
A description of a data object.
A data object identifier for use in the
Module interface.A function identifier for use in the
Module interface.A
Module is a utility for collecting functions and data objects, and linking them together.This provides a view to the state of a module which allows
ir::ExternalNames to be translated
into FunctionDeclarations and DataDeclarations.Enums
A declared name may refer to either a function or data declaration
This specifies how data is to be initialized.
Linkage refers to where an entity is defined and who can see it.
Error messages for all
Module and Backend methodsTraits
A
Backend implements the functionality needed to support a Module.Type Definitions
A convenient alias for a
Result that uses ModuleError as the error type.