[−][src]Enum cranelift_module::Linkage
Linkage refers to where an entity is defined and who can see it.
Variants
ImportDefined outside of a module.
LocalDefined inside the module, but not visible outside it.
PreemptibleDefined inside the module, visible outside it, and may be preempted.
ExportDefined inside the module, and visible outside it.
Methods
impl Linkage[src]
pub fn is_definable(self) -> bool[src]
Test whether this linkage can have a definition.
pub fn is_final(self) -> bool[src]
Test whether this linkage will have a definition that cannot be preempted.