pub enum ModuleError {
    Undeclared(String),
    IncompatibleDeclaration(String),
    IncompatibleSignature(StringSignatureSignature),
    DuplicateDefinition(String),
    InvalidImportDefinition(String),
    Compilation(CodegenError),
    Backend(String),
}
Error messages for all Module and Backend methods

Variants

Undeclared(String)

Indicates an identifier was used before it was declared

IncompatibleDeclaration(String)

Indicates an identifier was used as data/function first, but then used as the other

IncompatibleSignature(StringSignatureSignature)

Indicates a function identifier was declared with a different signature than declared previously

DuplicateDefinition(String)

Indicates an identifier was defined more than once

InvalidImportDefinition(String)

Indicates an identifier was defined, but was declared as an import

Compilation(CodegenError)

Wraps a cranelift-codegen error

Backend(String)

Wraps a generic error from a backend