Struct cranelift_module::ModuleNamespace [−][src]
pub struct ModuleNamespace<'a, B: 'a> where
B: Backend, { /* fields omitted */ }This provides a view to the state of a module which allows ir::ExternalNames to be translated
into FunctionDeclarations and DataDeclarations.
Methods
impl<'a, B> ModuleNamespace<'a, B> where
B: Backend, [src]
impl<'a, B> ModuleNamespace<'a, B> where
B: Backend, pub fn get_function_decl(&self, name: &ExternalName) -> &FunctionDeclaration[src]
pub fn get_function_decl(&self, name: &ExternalName) -> &FunctionDeclarationGet the FunctionDeclaration for the function named by name.
pub fn get_data_decl(&self, name: &ExternalName) -> &DataDeclaration[src]
pub fn get_data_decl(&self, name: &ExternalName) -> &DataDeclarationGet the DataDeclaration for the function named by name.
pub fn get_function_definition(
&self,
name: &ExternalName
) -> (Option<&B::CompiledFunction>, &str, &Signature)[src]
pub fn get_function_definition(
&self,
name: &ExternalName
) -> (Option<&B::CompiledFunction>, &str, &Signature)Get the definition for the function named by name, along with its name
and signature.
pub fn get_data_definition(
&self,
name: &ExternalName
) -> (Option<&B::CompiledData>, &str, bool)[src]
pub fn get_data_definition(
&self,
name: &ExternalName
) -> (Option<&B::CompiledData>, &str, bool)Get the definition for the data object named by name, along with its name
and writable flag
pub fn is_function(&self, name: &ExternalName) -> bool[src]
pub fn is_function(&self, name: &ExternalName) -> boolReturn whether name names a function, rather than a data object.